@@ -64,20 +64,28 @@ mod impls;
 mod debug_list;
 mod debug_struct;
 mod debug_tuple;
-use debug_list::DebugList;
-use debug_struct::DebugStruct;
-use debug_tuple::DebugTuple;
+mod debug_tuple_struct;
+pub use debug_list::DebugList;
+pub use debug_struct::DebugStruct;
+pub use debug_tuple::DebugTuple;
+pub use debug_tuple_struct::DebugTupleStruct;
 
 #[cfg(feature = "pretty")]
+#[cfg_attr(docsrs, doc(cfg(feature = "pretty")))]
 mod pretty;
 #[cfg(feature = "pretty")]
+#[cfg_attr(docsrs, doc(cfg(feature = "pretty")))]
 pub use pretty::debug;
 
 #[cfg(feature = "colors")]
+#[cfg_attr(docsrs, doc(cfg(feature = "colors")))]
 mod colors;
 #[cfg(feature = "colors")]
+#[cfg_attr(docsrs, doc(cfg(feature = "colors")))]
 pub use colors::color;
 
+#[cfg(feature = "derive")]
+#[cfg_attr(docsrs, doc(cfg(feature = "derive")))]
 pub use dbg_pls_derive::DebugPls;
 
 /// Syntax aware pretty-printed debug formatting.
@@ -85,7 +93,72 @@ pub use dbg_pls_derive::DebugPls;
 /// `DebugPls` should format the output in a programmer-facing, debugging context.
 ///
 /// Generally speaking, you should just `derive` a `Debug` implementation.
+///
+/// # Examples
+///
+/// Deriving an implementation:
+///
+/// ```
+/// use dbg_pls::{debug, DebugPls};
+/// #[derive(DebugPls)]
+/// struct Point {
+///     x: i32,
+///     y: i32,
+/// }
+///
+/// let origin = Point { x: 0, y: 0 };
+///
+/// assert_eq!(format!("The origin is: {}", debug(&origin)), "The origin is: Point { x: 0, y: 0 }");
+/// ```
+///
+/// Manually implementing:
+///
+/// ```
+/// use dbg_pls::{debug, DebugPls, Formatter};
+/// struct Point {
+///     x: i32,
+///     y: i32,
+/// }
+///
+/// impl DebugPls for Point {
+///     fn fmt(&self, f: Formatter<'_>) {
+///         f.debug_struct("Point")
+///          .field("x", &self.x)
+///          .field("y", &self.y)
+///          .finish()
+///     }
+/// }
+///
+/// let origin = Point { x: 0, y: 0 };
+///
+/// assert_eq!(format!("The origin is: {}", debug(&origin)), "The origin is: Point { x: 0, y: 0 }");
+/// ```
 pub trait DebugPls {
+    /// Formats the value using the given formatter.
+    ///
+    /// # Examples
+    ///
+    /// ```
+    /// use dbg_pls::{debug, DebugPls, Formatter};
+    /// use std::fmt;
+    ///
+    /// struct Position {
+    ///     longitude: f32,
+    ///     latitude: f32,
+    /// }
+    ///
+    /// impl DebugPls for Position {
+    ///     fn fmt(&self, f: Formatter<'_>) {
+    ///         f.debug_tuple()
+    ///          .field(&self.longitude)
+    ///          .field(&self.latitude)
+    ///          .finish()
+    ///     }
+    /// }
+    ///
+    /// let position = Position { longitude: 1.987, latitude: 2.983 };
+    /// assert_eq!(format!("{}", debug(&position)), "(1.987, 2.983)");
+    /// ```
     fn fmt(&self, f: Formatter<'_>);
 }
 
@@ -107,8 +180,11 @@ impl<'a> Formatter<'a> {
     pub fn debug_struct(self, name: &str) -> DebugStruct<'a> {
         DebugStruct::new(self, name)
     }
-    pub fn debug_tuple(self, name: &str) -> DebugTuple<'a> {
-        DebugTuple::new(self, name)
+    pub fn debug_tuple(self) -> DebugTuple<'a> {
+        DebugTuple::new(self)
+    }
+    pub fn debug_tuple_struct(self, name: &str) -> DebugTupleStruct<'a> {
+        DebugTupleStruct::new(self, name)
     }
     pub fn debug_list(self) -> DebugList<'a> {
         DebugList::new(self)
